.. ==================================================
.. FOR YOUR INFORMATION
.. --------------------------------------------------
.. -*- coding: utf-8 -*- with BOM.

.. include:: ../Includes.txt


.. _introduction:

Introduction
============

privacyIDEA is an Extension the changes the authentication in the backend and
in the frontend.

.. _what-it-does:

What does it do?
----------------

This is an Authentication Extension, which allows you to authenticate
with a second factor (possession) against privacyIDEA.

`privacyIDEA`_ is a system to manage authentication devices like OTP-Tokens,
Yubikeys, Google Authenticator, FreeOTP, One Time Passwords via Email and via
SMS and many more.

The great thing about privacyIDEA is, that you do not need to trust a service
provider,
since you can run *your own privacyIDEA* installation in your network or
data center. *Your* server, *your* keys, *your* data and *your* control.

You can setup one privacyIDEA system to manage all authentication devices of
all your users and customers. Several TYPO3 installations can authenticate
against this centrally managed privacyIDEA installation under your control.

For more information about installing a privacyIDEA system, please refer to
the `external documentation`_ or take a look at this `video
<https://www.youtube.com/watch?v=YzQPA3fQuYQ>`_.

For more information about configuring the privacyIDEA extension for TYPO3,
please refer to :ref:`configuration`.

.. _privacyIDEA: https://privacyidea.org
.. _external documentation: .. _install documentation: https://privacyidea.readthedocs.org/en/latest/installation/index.html
